@@ -1,7 +1,6 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.metrics.num_properties import NumProperties
+from toscametrics.blueprint.num_properties import NumProperties
 
 
 yaml_0 = 'tosca_definitions_version: tosca_simple_yaml_1_0\n\nimports:\n  - paypalpizzastore_nodejs_app.yaml'
@@ -16,16 +15,13 @@ yaml_7 = 'tosca_definitions_version: tosca_simple_yaml_1_0\ntopology_template:\n
 
 
 @parameterized_class([
-   { 'yaml': yaml_0, 'expected': 0},
-   { 'yaml': yaml_7, 'expected': 7}
+   {'yaml': yaml_0, 'expected': 0},
+   {'yaml': yaml_7, 'expected': 7}
 ])
 class TestNumPropertiesCount(unittest.TestCase):
     def setUp(self):
-        self.yaml = StringIO(self.yaml.expandtabs(2))
+        self.yaml = self.yaml.expandtabs(2)
 
-    def tearDown(self):
-        self.yaml.close()
-    
     def test(self):
         self.assertEqual(NumProperties(self.yaml).count(), self.expected)
 
