@@ -1,7 +1,6 @@
 import unittest
 from parameterized import parameterized_class
-from io import StringIO
-from toscametrics.yml.num_tokens import NumTokens
+from toscametrics.general.num_tokens import NumTokens
 
 yaml_12_1 = 'tosca_definitions_version: tosca_simple_yaml_1_0\n\ndescription: Template for deploying a single server ' \
             'with predefined properties. '
@@ -11,16 +10,13 @@ yaml_30_1 = 'tosca_definitions_version: tosca_simple_yaml_1_0\n\ndescription: Te
 
 
 @parameterized_class([
-   { 'yaml': yaml_12_1, 'expected': 12},
-   { 'yaml': yaml_30_1, 'expected': 30}
+   {'yaml': yaml_12_1, 'expected': 12},
+   {'yaml': yaml_30_1, 'expected': 30}
 ])
 class TestNumTokensCount(unittest.TestCase):
 
     def setUp(self):
-        self.yaml = StringIO(self.yaml.expandtabs(2))
-
-    def tearDown(self):
-        self.yaml.close()
+        self.yaml = self.yaml.expandtabs(2)
 
     def test(self):
         self.assertEqual(NumTokens(self.yaml).count(), self.expected)
